# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon FSx'
prefix = 'fsx'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateBackup = Action('CreateBackup')
CreateFileSystem = Action('CreateFileSystem')
CreateFileSystemFromBackup = Action('CreateFileSystemFromBackup')
DeleteBackup = Action('DeleteBackup')
DeleteFileSystem = Action('DeleteFileSystem')
DescribeBackups = Action('DescribeBackups')
DescribeFileSystems = Action('DescribeFileSystems')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateFileSystem = Action('UpdateFileSystem')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Application Auto Scaling'
prefix = 'application-autoscaling'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DeleteScalingPolicy = Action('DeleteScalingPolicy')
DeleteScheduledAction = Action('DeleteScheduledAction')
DeregisterScalableTarget = Action('DeregisterScalableTarget')
DescribeScalableTargets = Action('DescribeScalableTargets')
DescribeScalingActivities = Action('DescribeScalingActivities')
DescribeScalingPolicies = Action('DescribeScalingPolicies')
DescribeScheduledActions = Action('DescribeScheduledActions')
PutScalingPolicy = Action('PutScalingPolicy')
PutScheduledAction = Action('PutScheduledAction')
RegisterScalableTarget = Action('RegisterScalableTarget')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Pinpoint SMS and Voice Service'
prefix = 'sms-voice'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateConfigurationSet = Action('CreateConfigurationSet')
CreateConfigurationSetEventDestination = \
    Action('CreateConfigurationSetEventDestination')
DeleteConfigurationSet = Action('DeleteConfigurationSet')
DeleteConfigurationSetEventDestination = \
    Action('DeleteConfigurationSetEventDestination')
GetConfigurationSetEventDestinations = \
    Action('GetConfigurationSetEventDestinations')
ListConfigurationSets = Action('ListConfigurationSets')
SendVoiceMessage = Action('SendVoiceMessage')
UpdateConfigurationSetEventDestination = \
    Action('UpdateConfigurationSetEventDestination')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Kinesis Firehose'
prefix = 'firehose'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateDeliveryStream = Action('CreateDeliveryStream')
DeleteDeliveryStream = Action('DeleteDeliveryStream')
DescribeDeliveryStream = Action('DescribeDeliveryStream')
ListDeliveryStreams = Action('ListDeliveryStreams')
ListTagsForDeliveryStream = Action('ListTagsForDeliveryStream')
PutRecord = Action('PutRecord')
PutRecordBatch = Action('PutRecordBatch')
StartDeliveryStreamEncryption = Action('StartDeliveryStreamEncryption')
StopDeliveryStreamEncryption = Action('StopDeliveryStreamEncryption')
TagDeliveryStream = Action('TagDeliveryStream')
UntagDeliveryStream = Action('UntagDeliveryStream')
UpdateDestination = Action('UpdateDestination')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS XRay'
prefix = 'xray'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetTraces = Action('BatchGetTraces')
CreateGroup = Action('CreateGroup')
CreateSamplingRule = Action('CreateSamplingRule')
DeleteGroup = Action('DeleteGroup')
DeleteSamplingRule = Action('DeleteSamplingRule')
GetEncryptionConfig = Action('GetEncryptionConfig')
GetGroup = Action('GetGroup')
GetGroups = Action('GetGroups')
GetSamplingRules = Action('GetSamplingRules')
GetSamplingStatisticSummaries = Action('GetSamplingStatisticSummaries')
GetSamplingTargets = Action('GetSamplingTargets')
GetServiceGraph = Action('GetServiceGraph')
GetTimeSeriesServiceStatistics = Action('GetTimeSeriesServiceStatistics')
GetTraceGraph = Action('GetTraceGraph')
GetTraceSummaries = Action('GetTraceSummaries')
PutEncryptionConfig = Action('PutEncryptionConfig')
PutTelemetryRecords = Action('PutTelemetryRecords')
PutTraceSegments = Action('PutTraceSegments')
UpdateGroup = Action('UpdateGroup')
UpdateSamplingRule = Action('UpdateSamplingRule')
